==> scpdb-2.0.0.tgz: package/app/schedule.js <==
'use strict';

const schedule = require('node-schedule');
const {enqueue, log, logToDiscord} = require('./core/utils');

module.exports = function runScheduler() {
    if (process.env.DISABLE_SCHEDULER) {
        log('Scheduler is disabled');
        return;
    }
    log('Scheduler inited');

    schedule.scheduleJob('00 01 * * *', async () => {
        logToDiscord('Scheduling members import');
        await enqueue('members-import-init', ['scp-ru']);
    });

    schedule.scheduleJob('00 02 * * *', async () => {
        logToDiscord('Scheduling discord member roles sync');
        await enqueue('discord-roles-sync', []);
    });

    schedule.scheduleJob('00 * * * *', async () => {
        logToDiscord('Scheduling pages list import');
        await enqueue('pages-lists-import', []);
    });

    schedule.scheduleJob('00 00 * * *', async () => {
        logToDiscord('Scheduling featured daily rotation');
        await enqueue('featured-daily-rotation', []);
    });

    schedule.scheduleJob('02 00 * * 1', async () => {
        logToDiscord('Scheduling featured weekly rotation');
        await enqueue('featured-weekly-rotation', []);
    });

    schedule.scheduleJob('00 10 * * 1', async () => {
        logToDiscord('Scheduling featured weekly rotation');
        await enqueue('wiki-import-init', ['scp-ru']);
    });

    schedule.scheduleJob('05 02 */3 * *', async () => {
        logToDiscord('Scheduling full wikidot pages import');
        await enqueue('full-wiki-import-init', []);
    });

    schedule.scheduleJob('05 02 */4 * *', async () => {
        logToDiscord('Scheduling full wikidot pages import');
        await enqueue('object-titles-extraction', []);
    });
};

==> scpdb-2.0.8.tgz: package/app/schedule.js <==
'use strict';

const schedule = require('node-schedule');
const {enqueue, log, logToDiscord} = require('./core/utils');

module.exports = function runScheduler() {
    if (process.env.DISABLE_SCHEDULER) {
        log('Scheduler is disabled');
        return;
    }
    log('Scheduler inited');

    schedule.scheduleJob('00 01 * * *', async () => {
        logToDiscord('Scheduling members import');
        await enqueue('members-import-init', ['scp-ru']);
    });

    schedule.scheduleJob('00 02 * * *', async () => {
        logToDiscord('Scheduling discord member roles sync');
        await enqueue('discord-roles-sync', []);
    });

    schedule.scheduleJob('00 * * * *', async () => {
        await enqueue('pages-lists-import', []);
    });

    schedule.scheduleJob('00 00 * * *', async () => {
        logToDiscord('Scheduling featured daily rotation');
        await enqueue('featured-daily-rotation', []);
    });

    schedule.scheduleJob('02 00 * * 1', async () => {
        logToDiscord('Scheduling featured weekly rotation');
        await enqueue('featured-weekly-rotation', []);
    });

    schedule.scheduleJob('00 10 * * 1', async () => {
        logToDiscord('Scheduling featured weekly rotation');
        await enqueue('wiki-import-init', ['scp-ru']);
    });

    schedule.scheduleJob('05 02 */7 * *', async () => {
        logToDiscord('Scheduling full wikidot pages import');
        await enqueue('full-wiki-import-init', []);
    });

    schedule.scheduleJob('05 20 */7 * *', async () => {
        logToDiscord('Scheduling object titles extraction');
        await enqueue('object-titles-extraction', []);
    });
};
